Fix mixed dot for Jenkins rocm_2_0
Cette révision appartient à :
@@ -1403,7 +1403,7 @@ THE SOFTWARE.
|
||||
}
|
||||
|
||||
// Math functions
|
||||
#if (__hcc_workweek__ >= 19015) || defined(__HIP_CLANG_ONLY__)
|
||||
#if (__hcc_workweek__ >= 19015) || __HIP_CLANG_ONLY__
|
||||
inline
|
||||
__device__
|
||||
float amd_mixed_dot(__half2 a, __half2 b, float c, bool saturate) {
|
||||
|
||||
@@ -53,7 +53,7 @@ extern "C"
|
||||
typedef _Float16 __2f16 __attribute__((ext_vector_type(2)));
|
||||
typedef short __2i16 __attribute__((ext_vector_type(2)));
|
||||
|
||||
#if (__hcc_workweek__ >= 19015) || defined(__HIP_CLANG_ONLY__)
|
||||
#if (__hcc_workweek__ >= 19015) || __HIP_CLANG_ONLY__
|
||||
__device__ __attribute__((const)) float __ockl_fdot2(__2f16 a, __2f16 b, float c, bool s);
|
||||
#endif
|
||||
|
||||
|
||||
@@ -121,7 +121,7 @@ uint64_t __make_mantissa(const char* tagp)
|
||||
}
|
||||
|
||||
// DOT FUNCTIONS
|
||||
#if (__hcc_workweek__ >= 19015) || defined(__HIP_CLANG_ONLY__)
|
||||
#if (__hcc_workweek__ >= 19015) || __HIP_CLANG_ONLY__
|
||||
__DEVICE__
|
||||
inline
|
||||
int amd_mixed_dot(short2 a, short2 b, int c, bool saturate) {
|
||||
|
||||
@@ -29,7 +29,7 @@ THE SOFTWARE.
|
||||
#endif
|
||||
|
||||
// DOT FUNCTIONS
|
||||
#if (__hcc_workweek__ >= 19015) || defined(__HIP_CLANG_ONLY__)
|
||||
#if (__hcc_workweek__ >= 19015) || __HIP_CLANG_ONLY__
|
||||
__device__
|
||||
__attribute__((const))
|
||||
int __ockl_sdot2(
|
||||
|
||||
@@ -32,7 +32,7 @@ THE SOFTWARE.
|
||||
|
||||
|
||||
__global__ void DotFunctions(bool* result) {
|
||||
#if (__hcc_workweek__ >= 19015) || defined(__HIP_CLANG_ONLY__)
|
||||
#if (__hcc_workweek__ >= 19015) || __HIP_CLANG_ONLY__
|
||||
// Dot Functions
|
||||
short2 sa{1}, sb{1};
|
||||
result[0] = amd_mixed_dot(sa, sb, 1, result[0]) && result[0];
|
||||
|
||||
@@ -157,7 +157,7 @@ void __half2Test(bool* result, __half2 a) {
|
||||
result[0] = !(a < a) && result[0];
|
||||
result[0] = !(a > a) && result[0];
|
||||
|
||||
#if (__hcc_workweek__ >= 19015) || defined(__HIP_CLANG_ONLY__)
|
||||
#if (__hcc_workweek__ >= 19015) || __HIP_CLANG_ONLY__
|
||||
// Dot Functions
|
||||
result[0] = amd_mixed_dot(a, a, 1, 1) && result[0];
|
||||
#endif
|
||||
|
||||
Référencer dans un nouveau ticket
Bloquer un utilisateur